lenso-platform-runtime 0.1.17

docs.rs failed to build lenso-platform-runtime-0.1.17
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: lenso-platform-runtime-0.1.13